*****Journal of Economic Growth Replication File

set more off
capture log close
log using "Analysis_JoEG.log", replace

u data_joeg.dta, clear


******Tables

*Table 1: Descriptive Statistics
sum f_comm share_gym2 gemsteuer_pc mpopulation share_ev_1910 prussia
sum f_comm share_gym2 gemsteuer_pc mpopulation share_ev_1910 prussia if sample


*Table 2: Education and Church Attendance: Panel Estimates for German Cities, 1890-1930
reg f_comm share_gym2 gemsteuer_pc mpopulation prussia share_ev_1910 i.year, cl(kk_id)  
reg f_comm share_gym2 gemsteuer_pc mpopulation prussia share_ev_1910 i.year if year<1914, cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)  
preserve
keep if sample==1
keep matching year kk_id f_comm share_gym2 gemsteuer_pc mpopulation schueler_h2_
reshape wide f_comm share_gym2 gemsteuer_pc mpopulation schueler_h2_, i(matching) j(year)
for num 1930 1913 \ num 1890 1890: gen d_f_comm_XY = f_comm_X - f_comm_Y \ gen d_share_gym2_XY = share_gym2X - share_gym2Y \ gen d_mpop_XY = mpopulationX - mpopulationY \ gen d_gemsteu_XY = gemsteuer_pc_X - gemsteuer_pc_Y
for num 19301890 19131890: reg d_f_comm_X d_share_gym2_X d_gemsteu_X d_mpop_X, cl(kk_id)
restore


*Table 3: Robustness to Changes in Age, Gender, Migration, Universities and Secular Schools
xtreg f_comm share_gym2 gemsteuer_pc mpopulation share_under20_ share_over60_ i.year d_kas90 , fe cl(kk_id) 
xtreg f_comm gym_under20_2 gemsteuer_pc mpopulation share_under20_ share_over60_ i.year d_kas90 , fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation share_female i.year, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year share_zugezogen, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation uni share_stud i.year, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation shareev i.year, fe cl(kk_id)  


*Table 4: Robustness to Changes in Industry Structure, Wefare Spending, and Political Vote Shares
xtreg f_comm share_gym2 gemsteuer_pc mpopulation perc_secB_ i.year, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation perc_secB_ perc_secC_ i.year, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation perc_sec_BC i.year, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation armenpflegepc i.year, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation share_spd i.year, fe cl(kk_id)  
xtreg f_comm share_gym2 gemsteuer_pc mpopulation share_nat2 i.year, fe cl(kk_id)  


*Table 5: Alternative Income Measures
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)  
xtreg f_comm share_gym2 ekst_p_pc mpopulation i.year if year<1914, fe cl(kk_id)  
xtreg f_comm share_gym2 teainc mpopulation i.year if year<1914, fe cl(kk_id) 
xtreg f_comm share_gym2 gemsteuer_pc ekst_p_pc teainc mpopulation i.year if year<1914, fe cl(kk_id) 
xtreg f_comm gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id) 
xtreg f_comm mpopulation ekst_p_pc i.year if year<1914, fe cl(kk_id) 
xtreg f_comm mpopulation teainc i.year if year<1914, fe cl(kk_id) 

 
* Table 6: Alternative Lag Structures
xtset matching time
xtreg f_comm share_gym2 L1.share_gym2  gemsteuer_pc mpopulation i.year, fe cl(kk_id)
xtreg f_comm share_gym2 L1.share_gym2  gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm  share_gym2 L1.share_gym2 L2.share_gym2 gemsteuer_pc mpopulation i.year, fe cl(kk_id)
xtreg f_comm share_gym2 L1.share_gym2 L2.share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm L1.share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm L2.share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm L3.share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg share_gym2  L1.f_comm  gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)


*Table 7: Dynamic Panel Models and City-Specific Trends
sort matching time
xtreg f_comm L1.f_comm share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm L1.f_comm L2.share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm L1.f_comm share_gym2 L1.share_gym2 L2.share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm L1.f_comm share_gym2 L2.share_gym2 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xi: xtreg f_comm L1.f_comm share_gym2 gemsteuer_pc mpopulation i.year i.matching|year if year<1914, fe cl(kk_id)


*Table 8: Instrumental-Variable Estimates
replace sc_h=sc_h/10000
replace sc_gym_m=sc_gym_m/10000
xtivreg2 f_comm (L1.share_gym2 = L1.sc_h) gemsteuer_pc mpopulation _Iyear_1900 _Iyear_1905 _Iyear_1910 _Iyear_1913 if year<1914, fe first 
xtivreg2 f_comm (L2.share_gym2 = L2.sc_h) gemsteuer_pc mpopulation _Iyear_1905 _Iyear_1910 _Iyear_1913 if year<1914, fe first 
xtivreg2 f_comm (L1.sha_st_gym_m = L1.sc_gym_m) gemsteuer_pc mpopulation _Iyear_1900 _Iyear_1905 _Iyear_1910 if year<1914, fe first 
xtivreg2 f_comm (L2.sha_st_gym_m = L2.sc_gym_m) gemsteuer_pc mpopulation _Iyear_1905 _Iyear_1910 _Iyear_1913 if year<1914, fe first 

 
*Table 9: Different Types of Advanced Schools 
xtreg f_comm sha_st_h3 gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm sha_st_h_m2 share_gym2_w gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm share_gym2_w sha_st_hum_m sha_st_rgym_m sha_st_oreal_m sha_st_real_m sha_st_sh_m gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm share_gym2_w gemsteuer_pc mpopulation i.year if year<1914 & sha_st_h3~=., fe cl(kk_id)
xtreg f_comm sha_st_hum_m gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm sha_st_rgym_m gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm sha_st_oreal_m gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)
xtreg f_comm sha_st_3_m gemsteuer_pc mpopulation i.year if year<1914, fe cl(kk_id)



******Figures

*Figure 2: Education and Church Attendance: Levels and Changes 
preserve
keep if sample 
scatter f_comm share_gym2 if year==1900, mcolor(black) msize(medsmall) msymbol(circle) graphregion(fcolor(white))  || lfit f_comm share_gym2 if year==1900, legend(off) lcolor(black) ytitle("Church attendance, 1900") xtitle("Enrollment rate in advanced schools, 1900")
restore

preserve
keep if sample 
keep matching year f_comm share_gym2 gemsteuer_pc mpopulation 
reshape wide f_comm share_gym2 gemsteuer_pc mpopulation, i(matching) j(year)
gen d_f_comm_9013 = f_comm_1913 - f_comm_1890
gen d_share_gym2_9013 = share_gym21913 - share_gym21890
scatter d_f_comm_9013 d_share_gym2_9013, mcolor(black) msize(medsmall) msymbol(circle) graphregion(fcolor(white))  || lfit d_f_comm_9013 d_share_gym2_9013, legend(off) lcolor(black) ytitle("Change in church attendance, 1890-1913") xtitle("Change in enrollment rate in advanced schools, 1890-1913")
restore



******Appendix

*Table A1: Robustness Samples and Samples by Protestant Share
preserve
keep if sample==1
keep matching year kk_id f_comm share_gym2 gemsteuer_pc mpopulation 
reshape wide f_comm share_gym2 gemsteuer_pc mpopulation, i(matching) j(year)
for any 1890: drop if f_comm_X==. \ drop if gemsteuer_pc_X==. \ drop if share_gym2X==.
reshape long
gen time=. 
for num 1/8 \ num 1890 1895 1900 1905 1910 1913 1925 1930: replace time=X if year==Y
xtset matching time
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year, fe cl(kk_id)
restore

xtset matching time
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if imputed~=1, fe cl(kk_id)
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if relkksize<2, fe cl(kk_id)
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if ror>1, fe cl(kk_id)
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if share_ev_1910>0.5, fe cl(kk_id)
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if share_ev_1910<0.5, fe cl(kk_id)
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if share_ev_1910>0.75, fe cl(kk_id)
xtreg f_comm share_gym2 gemsteuer_pc mpopulation i.year if share_ev_1910<0.75, fe cl(kk_id)


*Table A2: Bivariate Association between Different Income Measures and Advanced-School Enrollment
replace gemsteuer_pc=gemsteuer_pc/100
xtreg share_gym2 gemsteuer_pc i.year if sample==1, fe cl(kk_id)
xtreg share_gym2 ekst_p_pc i.year if sample==1, fe cl(kk_id) 
xtreg share_gym2 teainc i.year if sample==1, fe cl(kk_id)
xtreg gemsteuer_pc share_gym2  i.year if sample==1, fe cl(kk_id) 
xtreg gemsteuer_pc ekst_p_pc i.year if sample==1, fe cl(kk_id)
xtreg gemsteuer_pc teainc i.year if sample==1, fe cl(kk_id) 
xtreg ekst_p_pc share_gym2  i.year if sample==1, fe cl(kk_id) 
xtreg ekst_p_pc gemsteuer_pc i.year if sample==1, fe cl(kk_id) 
xtreg ekst_p_pc teainc i.year if sample==1, fe cl(kk_id) 
xtreg teainc share_gym2  i.year if sample==1, fe cl(kk_id)
xtreg teainc  gemsteuer_pc i.year if sample==1, fe cl(kk_id) 
xtreg teainc  ekst_p_pc i.year if sample==1, fe cl(kk_id) 

log close
